from setuptools import setup

setup(
    name="pgk",
    version="0.1.3",
    license="MIT",
    author="ExtraMobs",
    author_email="extramobs@hotmail.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3.10",
    ],
    url="https://github.com/ExtraMobs/pgk",
    keywords="PyGameKit",
    python_requires=">=3.10",
    install_requires=[
        "pygame",
        "screeninfo"
    ]
)
